@@ -2,7 +2,7 @@
 #' @description Calculates sample size and composition for a two-stage cluster sampling design to estimate a total.
 #' @param psu.ssu \code{\link{data.frame}} with all primary sampling units (PSU). First column contains PSU unique identifiers. Second column contains \code{\link{numeric}} PSU sizes.
 #' @param psu.x \code{\link{data.frame}}. Each row corresponds to a secondary sampling unit (SSU) surveyed in a pilot study. First column contains the PSU identifiers to which the ssu belongs to. Second column contains the totals observed in the ssu and must be \code{\link{numeric}}.
-#' @param level the confidence level required. It must be \code{\link{numeric}} between 0 and 1 inclusive.
+#' @param conf.level the confidence level required. It must be \code{\link{numeric}} between 0 and 1 inclusive.
 #' @param error the maximum relative difference between the estimate and the unknown population value. It must be \code{\link{numeric}} between 0 and 1 inclusive.
 #' @param cost the ratio of the cost of sampling a PSU to the cost of sampling a SSU.
 #' @return Matrix with the sample size and composition and with variability estimates.
@@ -21,17 +21,17 @@
 #' data(pilot)
 #' 
 #' # Calculate sample size and composition.
-#' (sample.sc <- Calculate2StageSampleSize(psu.ssu, pilot, level = 0.95, error = 0.1, cost = 4))
+#' (sample.sc <- Calculate2StageSampleSize(psu.ssu, pilot, conf.level = 0.95, error = 0.1, cost = 4))
 
-Calculate2StageSampleSize <- function(psu.ssu = NULL, psu.x = NULL, level = .95, error = 0.1, cost = 4) {
+Calculate2StageSampleSize <- function(psu.ssu = NULL, psu.x = NULL, conf.level = .95, error = 0.1, cost = 4) {
   if (length(intersect(psu.ssu[, 1], psu.x[, 1])) == 0) {
     stop('PSU identifiers must be equal in psu.ssu and in psu.x')
   }
-  if (level > 1 | level < 0) {
-    stop('level must be a number between 0 and 1 inclusive.')
+  if (conf.level > 1 | conf.level < 0) {
+    stop('conf.level must be a number between 0 and 1 inclusive.')
   }
   if (error > 1 | error < 0) {
-    stop('level must be a number between 0 and 1 inclusive.')
+    stop('error must be a number between 0 and 1 inclusive.')
   }
   psu.ssu.x <- merge(psu.ssu, psu.x, by = 1)
   M <- nrow(psu.ssu)
@@ -58,7 +58,7 @@ Calculate2StageSampleSize <- function(psu.ssu = NULL, psu.x = NULL, level = .95,
   if (nb < 2) {nb = 2}
   X <- sum(N / sum(nip) * tapply(psu.ssu.x[ , 3], 
                                  psu.ssu.x[ , 1], sum)) 
-  z <- abs(round(qnorm((1 - level) / 2, 0, 1), 2))
+  z <- abs(round(qnorm((1 - conf.level) / 2, 0, 1), 2))
   m <- ceiling(((z ^ 2) * sum((((N * xi) / nbp) - X) ^ 2)) / 
                  ((error ^ 2) * (X ^ 2) * (mp - 1)))
   if(m > M) {m  <-  M}
